@@ -652,19 +652,23 @@ class DirectoryDistributive(Distributive):
         if not parent:
             self._makeDirectory(self.directory)
 
+    def hasSystemDirectories(self):
+        return self.system_mounted or self.directory == '/'
+
     def mountSystemDirectories(self, skip=("remote",)):
         """
         Подключить к дистрибутиву системые ресурсы (/proc, /sys)
         :return:
         """
-        for obj in filter(lambda x: x['name'] not in skip, self.data):
-            target_path = path.join(self.directory, obj['target'])
-            if obj['type'] == 'bind':
-                self._mountToBind(obj['source'], target_path)
-            else:
-                self._mountToDirectory(obj['source'], target_path,
-                                       "-t %s" % obj['type'])
-        self.system_mounted = True
+        if not self.system_mounted:
+            for obj in filter(lambda x: x['name'] not in skip, self.data):
+                target_path = path.join(self.directory, obj['target'])
+                if obj['type'] == 'bind':
+                    self._mountToBind(obj['source'], target_path)
+                else:
+                    self._mountToDirectory(obj['source'], target_path,
+                                           "-t %s" % obj['type'])
+            self.system_mounted = True
 
     def umountSystemDirectories(self):
         for obj in reversed(self.data):
