@@ -236,6 +236,8 @@ class Install(MethodsInterface):
             self.install_grub_uefi(cmd_grub_install, prefix_boot, target)
         # не UEFI установка
         else:
+            # необходимо удалить запись /boot/efi из текущей системы
+            # при выполнении cl-setup-boot --mbr
             if self.clVars.Get('os_uefi'):
                 self.update_efi_fstab()
                 self.mount_efi_fstab()
@@ -247,6 +249,9 @@ class Install(MethodsInterface):
         """
         # получить загрузочный раздел (если есть /boot, то
         # он является загрузочным иначе корень)
+        chroot_cmd = getProgPath('/usr/bin/chroot')
+        chroot_dn = target.getDirectory()
+
         for boot_path in ("/boot", "/"):
             boot_disk = self.clVars.Select("os_install_disk_dev",
                                            where="os_install_disk_mount",
@@ -264,18 +269,33 @@ class Install(MethodsInterface):
         else:
             platform = []
         # прописать GRUB2 на все указанные диски
-        for mbr_disk in self.clVars.Get('os_install_mbr'):
-            grub_process = process(cmd_grub_install,
-                                   "--boot-directory=%s" % pathJoin(
-                                       prefix_boot,
-                                       target.getBootDirectory()),
-                                   mbr_disk, "--force", *platform,
-                                   stderr=STDOUT, envdict=os.environ)
-            if grub_process.failed():
-                raise DistributiveError(
-                    _("Failed to install the bootloader"))
+        targetdir = target.convertToDirectory()
+        if not targetdir.hasSystemDirectories():
+            targetdir.mountSystemDirectories()
+        try:
+            for mbr_disk in self.clVars.Get('os_install_mbr'):
+                grub_process = process(
+                    chroot_cmd,
+                    chroot_dn,
+                    cmd_grub_install,
+                    "--boot-directory=/%s" % path.relpath(target.getBootDirectory(),
+                        chroot_dn),
+                    mbr_disk, "--force", *platform,
+                    stderr=STDOUT, envdict=os.environ)
+                if grub_process.failed():
+                    raise DistributiveError(
+                        _("Failed to install the bootloader"))
+        finally:
+            if targetdir.system_mounted:
+                targetdir.umountSystemDirectories()
 
     def update_efi_fstab(self):
+        """
+        Обновляем (или удаляем) запись /boot/efi в текущем /etc/fstab
+        
+        Удаление используется в случае, если выполняется обновление загрузчика
+        в не EFI системе, хотя до этого она была установлена как EFI
+        """
         fstab_fn = pathJoin(self.clVars.Get('cl_chroot_path'), "/etc/fstab")
         re_efi_record = re.compile("^(# /boot/efi|\S+\s/boot/efi).*\n",
                                    flags=re.M)
@@ -328,6 +348,11 @@ class Install(MethodsInterface):
         return PartitionDistributive(None).formatPartition(dev, format, label)
 
     def mount_efi_fstab(self):
+        """
+        Подключить /boot/efi (или отключить) согласно новым данным
+
+        Используется как для подключения /boot/efi, так и для отключения.
+        """
         oldmp_efi = self.clVars.select('os_disk_mount',
                                        os_disk_mount__startswith="/boot/efi")
         for dev, mp in self.clVars.ZipVars('os_install_disk_dev',
@@ -371,14 +396,14 @@ class Install(MethodsInterface):
         """
         Установить grub с UEFI загрузчиком
         """
-        efifulldir = pathJoin(target.getDirectory(), efidir)
+        chroot_cmd = getProgPath('/usr/bin/chroot')
+        chroot_dn = target.getDirectory()
         grub_params = [
-            "--boot-directory=%s" % pathJoin(
-                prefix_boot,
-                target.getBootDirectory()),
+            "--boot-directory=/%s" % path.relpath(target.getBootDirectory(),
+                chroot_dn),
             "--bootloader-id=%s" % efiname,
             "--target=x86_64-efi",
-            "--efi-directory=%s" % efifulldir,
+            "--efi-directory=%s" % efidir,
             "--force"]
         # проверяем наличие в nv-ram нужной нам записи для исключения повтора
         efi_boot_mgr = getProgPath('/usr/sbin/efibootmgr')
@@ -401,11 +426,21 @@ class Install(MethodsInterface):
         # в efivars
         if self.clVars.Get('os_install_root_type') == 'usb-hdd':
             grub_params.append("--removable")
-        grub_process = process(cmd_grub_install,
-                               *grub_params, stderr=STDOUT,
-                               envdict=os.environ)
-        if grub_process.failed():
-            raise DistributiveError(_("Failed to install the bootloader"))
+        targetdir = target.convertToDirectory()
+        if not targetdir.hasSystemDirectories():
+            targetdir.mountSystemDirectories()
+        try:
+            grub_process = process(
+                chroot_cmd,
+                chroot_dn,
+                cmd_grub_install,
+                *grub_params, stderr=STDOUT,
+                envdict=os.environ)
+            if grub_process.failed():
+                raise DistributiveError(_("Failed to install the bootloader"))
+        finally:
+            if targetdir.system_mounted:
+                targetdir.umountSystemDirectories()
         # проверяем успешность создания загрузочной записи
         # если среди загрузочных записей отсутствует запись
         # calculate и dmesg содержит сообщение об ошибке efivars -
