@@ -2367,6 +2367,11 @@ class VariableOsInstallFstabMountConf(DeviceHelper, ReadonlyVariable):
 
 
 class VariableOsInstallFstabEfiConf(VariableOsInstallFstabMountConf):
+    """
+    Переменная содержит часть fstab в которой содержится описание
+    подключения /boot/efi
+    """
+
     def get(self):
         devicesForFstab = self.Select([
             'os_install_disk_use',
@@ -2414,6 +2419,18 @@ class VariableClInstallType(Variable):
     def choice(self):
         return ["", "flash", "hdd"]
 
+    def check(self, value):
+        for dn in ("/proc", "/sys", "/dev", "/dev/pts"):
+            if not isMount(dn):
+                raise VariableError(_("%s is not mounted") %dn )
+        check_fn = '/run/.calculate-rw-check-%d' % os.getpid()
+        try:
+            with open(check_fn,'w') as f:
+                pass
+            os.unlink(check_fn)
+        except (IOError,OSError) as e:
+            raise VariableError(_("Failed to create data in /run"))
+
 
 class VariableOsInstallDiskSingle(Variable):
     """
