@@ -24,6 +24,7 @@ from calculate.lib.datavars import (Variable, ReadonlyVariable,
 from calculate.lib.utils.files import (readFile,
                                        typeFile, process, listDirectory,
                                        MAGIC_SYMLINK, MAGIC_COMPRESS)
+from calculate.lib.utils.kernel import InitrdFile
 
 from calculate.lib.cl_lang import setLocalTranslate
 
@@ -328,6 +329,10 @@ class KernelHelper(VariableInterface):
                                    filelist))
         return filter(lambda x: descr in x[1], filesWithType)
 
+    def getInitrdFiles(self, pathname):
+        filelist = map(lambda x: path.join(pathname, x), os.listdir(pathname))
+        return [x for x in filelist if path.exists(x) and InitrdFile.is_cpio(x)]
+
     def getInitrd(self, arch, shortname, chroot, kernel, suffix="",
                   notsuffix=""):
         """Get initrd for kernel"""
@@ -352,14 +357,14 @@ class KernelHelper(VariableInterface):
             origKernelVer = resKernelVer.group()
 
             bootdir = path.join(chroot, 'boot')
-            initramfsFiles = self.getFilesByType(bootdir, "ASCII cpio archive")
+            initramfsFiles = self.getInitrdFiles(bootdir)
             initramfsWithVer = \
                 filter(lambda x: (kernelVersion in x[1] or
                                   origKernelVer in x[1]) and \
                                  x[0].endswith(suffix) and \
                                  (
                                  not notsuffix or not x[0].endswith(notsuffix)),
-                       map(lambda x: (x[0], initrd_version_by_name(x[0])),
+                       map(lambda x: (x, initrd_version_by_name(x)),
                            initramfsFiles))
             if initramfsWithVer:
                 return path.split(min(initramfsWithVer,
