@@ -60,7 +60,8 @@ class Wsdl(WsdlBase):
         'native_error': (VariableError, DistributiveError, VolumesError,
                          DataVarsError, install.InstallError),
         # значения по умолчанию для переменных этого метода
-        'setvars': {'cl_action!': 'system', 'cl_install_type': 'hdd',
+        'setvars': {'cl_action!': 'system',
+                    'cl_chroot_status!': 'off', 'cl_install_type': 'hdd',
                     'cl_dispatch_conf': 'usenew'},
         # описание груп (список лямбда функций)
         'groups': [
@@ -156,7 +157,9 @@ class Wsdl(WsdlBase):
             'datavars': "install",
             'native_error': (VariableError, DistributiveError, VolumesError,
                              DataVarsError, install.InstallError),
-            'setvars': {'cl_action!': 'system', 'cl_install_type': 'flash',
+            'setvars': {'cl_action!': 'system',
+                        'cl_chroot_status!': 'off',
+                        'cl_install_type': 'flash',
                         'cl_protect_use_set!': 'off',
                         'cl_autopartition_set!': 'off',
                         'cl_dispatch_conf': 'usenew'},
